==> ploneazax-1.0.alpha1-plone2.1-zope2.8.tgz: PloneAzax/tests/test_menus.py <==
# -*- coding: UTF-8 -*-
# Copyright (c) 2006
# Authors:
#   David '/dev/null' Convent  <davconvent@gmail.com>
#   Daniel 'import pdb' Nouri
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

import unittest
from zope.testing import doctest
from Products.PloneTestCase import PloneTestCase
from Products.azax.tests.base import AzaxViewTestCase, FakeContent, \
                                     TestRequest, DebugTestRequest

from Products.Five.zcml import load_string, load_config

PloneTestCase.installProduct('PloneAzax')
#XXX we should test with unicode PloneTestCase.installProduct('PlacelessTranslationService')
PloneTestCase.setupPloneSite(products=['PloneAzax'])

import Products.azax
import Products.azax.tests
import Products.PloneAzax
from Products.PloneAzax import content_replacer
from Products.azax.tests.base import AzaxViewTestCase
 
class ContentActionMenusTestCase(AzaxViewTestCase, PloneTestCase.PloneTestCase):

    def afterSetUp(self):
        PloneTestCase.PloneTestCase.afterSetUp(self)
        AzaxViewTestCase.afterSetUp(self)
        load_config('configure.zcml', package=Products.PloneAzax)
        # Set up a fake view (with no content)
        # XXX commands will be rendered as data structures,
        # because we use DebugTestRequest instead of TestRequest.
        self.loginAsPortalOwner()
        # What we'd like to do is render templates in french, so that we know if
        # run into problems there.  For the time being, this statement has no effect.
        # XXX
        self.portal.REQUEST.form['language'] = 'fr'

        # Make sure we have the front page; the portal generator should take 
        # care of this, but let's not be dependent on that in the test
        # XXX 2.1 testsuite does not seem to create it
        if not 'front-page' in self.portal.objectIds():
            self.portal.invokeFactory('Document', 'front-page',
                                      title = 'Welcome to Plone')
            self.portal.setDefaultPage('front-page')

        self.fpage = self.portal['front-page']

    def beforeTearDown(self):
        PloneTestCase.PloneTestCase.beforeTearDown(self)
        AzaxViewTestCase.beforeTearDown(self)

    # --
    # test the Kss methods
    # --

    def testReplaceContentRegion(self):
        fakedebugrequest = DebugTestRequest()
        view = content_replacer.ContentView(self.fpage, fakedebugrequest)
        result = view.replaceContentRegion('contentview-edit', self.fpage.absolute_url())
        self.assertEqual([(r['name'], r['selector'], r['selectorType']) for r in result],
            [('replaceHTML', 'region-content', 'htmlid'),
            ('setAttribute', 'ul.contentViews li', 'css'),
            ('setAttribute', 'contentview-edit', 'htmlid')]
            )

    def testChangeViewTemplate(self):
        # Let's set the default page on front-page,
        # should set default layout of portal
        req = self.portal.REQUEST
        self.assertEqual(self.portal.getLayout(), 'folder_listing')
        view = content_replacer.ContentView(self.fpage, req)
        url = self.fpage.absolute_url() + '?templateId=atct_album_view'
        result = view.changeViewTemplate(url)
        self.assertEqual(self.portal.getLayout(), 'atct_album_view')
        
        resh = req.RESPONSE.headers
        self.assertEqual(resh['status'], '200 OK')
        # on Plone 2.1 we don't have this cookie
        statusmessages = req.RESPONSE.cookies.get('statusmessages', None)
        self.failUnless(not statusmessages or statusmessages.has_key('expires'), 'cookies not expired')

    def testKukitCutObject(self):
        fakedebugrequest = DebugTestRequest()
        view = content_replacer.ContentView(self.fpage, fakedebugrequest)
        result = view.cutObject()
        self.assertEqual([(r['name'], r['selector'], r['selectorType']) for r in result],
            [('replaceInnerHTML', 'div#content div.contentActions', 'css')]
            )

    def testCutObject(self):
        req = self.portal.REQUEST
        self.failIf(req.RESPONSE.cookies.has_key('__cp'), 'has cut cookie')
        view = content_replacer.ContentView(self.fpage, req)
        result = view.cutObject()
        resh = req.RESPONSE.headers
        self.assertEqual(resh['status'], '200 OK')
        self.failUnless(req.RESPONSE.cookies.has_key('__cp'), 'no cut cookie')
        
    def testKukitCopyObject(self):
        fakedebugrequest = DebugTestRequest()
        view = content_replacer.ContentView(self.fpage, fakedebugrequest)
        result = view.copyObject()
        self.assertEqual([(r['name'], r['selector'], r['selectorType']) for r in result],
            [('replaceInnerHTML', 'div#content div.contentActions', 'css')]
            )

    def testCopyObject(self):
        req = self.portal.REQUEST
        self.failIf(req.RESPONSE.cookies.has_key('__cp'), 'has copy cookie')
        view = content_replacer.ContentView(self.fpage, req)
        result = view.copyObject()
        resh = req.RESPONSE.headers
        self.assertEqual(resh['status'], '200 OK')
        self.failUnless(req.RESPONSE.cookies.has_key('__cp'), 'no copy cookies')

def test_suite():
    return unittest.TestSuite((
        unittest.makeSuite(ContentActionMenusTestCase),
        #doctest.DocTestSuite('Products.ATAzax.fields'),
        ))

==> ploneazax-1.1.alpha1-plone2.5-zope2.8.tgz: PloneAzax/tests/test_menus.py <==
# -*- coding: UTF-8 -*-
# Copyright (c) 2006
# Authors:
#   David '/dev/null' Convent  <davconvent@gmail.com>
#   Daniel 'import pdb' Nouri
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

import unittest
from zope.testing import doctest
from Products.PloneTestCase import PloneTestCase
from Products.azax.tests.base import AzaxViewTestCase, FakeContent, \
                                     TestRequest, DebugTestRequest

from Products.Five.zcml import load_string, load_config

PloneTestCase.installProduct('PloneAzax')
#XXX we should test with unicode PloneTestCase.installProduct('PlacelessTranslationService')
PloneTestCase.setupPloneSite(products=['PloneAzax'])

import Products.azax
import Products.azax.tests
import Products.PloneAzax
from Products.PloneAzax import content_replacer

class ContentActionMenusTestCase( PloneTestCase.PloneTestCase):

    def afterSetUp(self):
        PloneTestCase.PloneTestCase.afterSetUp(self)
        load_config('meta.zcml', package=Products.azax)
        load_config('configure.zcml', package=Products.azax)
        load_config('configure-unittest.zcml', package=Products.azax.tests)
        load_config('configure.zcml', package=Products.PloneAzax)
        # Set up a fake view (with no content)
        # XXX commands will be rendered as data structures,
        # because we use DebugTestRequest instead of TestRequest.
        self.loginAsPortalOwner()
        # What we'd like to do is render templates in french, so that we know if
        # run into problems there.  For the time being, this statement has no effect.
        # XXX
        self.portal.REQUEST.form['language'] = 'fr'
        self.fpage = self.portal['front-page']

    # --
    # test the Kss methods
    # --

    def testReplaceContentRegion(self):
        fakedebugrequest = DebugTestRequest()
        view = content_replacer.ContentView(self.fpage, fakedebugrequest)
        result = view.replaceContentRegion('contentview-edit', self.fpage.absolute_url())
        self.assertEqual([(r['name'], r['selector'], r['selectorType']) for r in result],
            [('replaceHTML', 'region-content', 'htmlid'),
            ('setAttribute', 'ul.contentViews li', 'css'),
            ('setAttribute', 'contentview-edit', 'htmlid')]
            )

    def testChangeViewTemplate(self):
        # Let's set the default page on front-page,
        # should set default layout of portal
        req = self.portal.REQUEST
        self.assertEqual(self.portal.getLayout(), 'folder_listing')
        view = content_replacer.ContentView(self.fpage, req)
        url = self.fpage.absolute_url() + '?templateId=atct_album_view'
        result = view.changeViewTemplate(url)
        self.assertEqual(self.portal.getLayout(), 'atct_album_view')
        
        resh = req.RESPONSE.headers
        self.assertEqual(resh['status'], '200 OK')
        self.failUnless(req.RESPONSE.cookies['statusmessages'].has_key('expires'), 'cookies not expired')

    def testKukitCutObject(self):
        fakedebugrequest = DebugTestRequest()
        view = content_replacer.ContentView(self.fpage, fakedebugrequest)
        result = view.cutObject()
        self.assertEqual([(r['name'], r['selector'], r['selectorType']) for r in result],
            [('replaceInnerHTML', 'div#content div.contentActions', 'css')]
            )

    def testCutObject(self):
        req = self.portal.REQUEST
        self.failIf(req.RESPONSE.cookies.has_key('__cp'), 'has cut cookie')
        view = content_replacer.ContentView(self.fpage, req)
        result = view.cutObject()
        resh = req.RESPONSE.headers
        self.assertEqual(resh['status'], '200 OK')
        self.failUnless(req.RESPONSE.cookies.has_key('__cp'), 'no cut cookie')
        
    def testKukitCopyObject(self):
        fakedebugrequest = DebugTestRequest()
        view = content_replacer.ContentView(self.fpage, fakedebugrequest)
        result = view.copyObject()
        self.assertEqual([(r['name'], r['selector'], r['selectorType']) for r in result],
            [('replaceInnerHTML', 'div#content div.contentActions', 'css')]
            )

    def testCopyObject(self):
        req = self.portal.REQUEST
        self.failIf(req.RESPONSE.cookies.has_key('__cp'), 'has copy cookie')
        view = content_replacer.ContentView(self.fpage, req)
        result = view.copyObject()
        resh = req.RESPONSE.headers
        self.assertEqual(resh['status'], '200 OK')
        self.failUnless(req.RESPONSE.cookies.has_key('__cp'), 'no copy cookies')

def test_suite():
    return unittest.TestSuite((
        unittest.makeSuite(ContentActionMenusTestCase),
        #doctest.DocTestSuite('Products.ATAzax.fields'),
        ))
